@@ -12,6 +12,8 @@ from typing import Literal
 from tkdev.devicon import Icon_Empty
 from tkdev.devresize import DevResize
 from tkdev.devnet import WindowEffect
+import warnings
+from deprecated.sphinx import deprecated
 
 try:
     from win32gui import *
@@ -61,10 +63,12 @@ def Install(Library, Basic=True, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/
 def Install_ALL(Basic=True, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
     Install("tkinter-tooltip", Basic=Basic, Pypi=Pypi)
     Install("pywin32", Basic=Basic, Pypi=Pypi)
-    Install("win32mica", Basic=Basic, Pypi=Pypi)
+    if sys.platform == "win32" and sys.getwindowsversion().build >= 22000:
+        Install("win32mica", Basic=Basic, Pypi=Pypi)
     Install("BlurWindow", Basic=Basic, Pypi=Pypi)
     Install("darkdetect", Basic=Basic, Pypi=Pypi)
     Install("tkcap", Basic=Basic, Pypi=Pypi)
+    Install("Deprecated", Basic=Basic, Pypi=Pypi)
 
 
 class AccentState(Enum):
@@ -157,6 +161,7 @@ def window_move(widget: tk.Widget, window: tk.Tk):
         ReleaseCapture()
         SendMessage(GetParent(window.winfo_id()), WM_SYSCOMMAND,
                     SC_MOVE + HTCAPTION, 0)
+
     widget.bind("<B1-Motion>", move)
 
 
@@ -181,7 +186,8 @@ def window_acrylic(window: tk.Tk, dark=False, acrylic: bool = False, hexColor: b
 
 
 def window_acrylic2(window: tk.Tk, shadow: bool = True):
-    effent = WindowEffect(GetParent(window.winfo_id()), isEnableShadow=shadow)
+    effent = WindowEffect()
+    effent.setAcrylicEffect(hWnd=GetParent(window.winfo_id()), isEnableShadow=shadow)
 
 
 def window_long(window: tk.Tk, long):
@@ -298,6 +304,7 @@ def window_custom_taskbar(window: tk.Tk):
     def over():
         hwnd = GetParent(window.winfo_id())
         res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_OVERLAPPEDWINDOW)
+        SetWindowPos(hwnd, NULL, 0, 0, 0, 0, SWP_NOSIZE | SWP_NOMOVE | SWP_NOZORDER | SWP_DRAWFRAME)
 
     window.after(1, over)
     window.update()
@@ -320,6 +327,13 @@ def window_add_taskbar(window: tk.Tk):
     window.after(1, lambda: window.wm_deiconify())
 
 
+def window_border(window: tk.Tk):
+    hWnd = GetParent(window.winfo_id())
+    SetWindowLong(hWnd, GWL_STYLE, GetWindowLong(hWnd, GWL_STYLE) & ~WS_CAPTION)
+    SetWindowPos(hWnd, NULL, 0, 0, 0, 0, SWP_NOSIZE | SWP_NOMOVE | SWP_NOZORDER | SWP_DRAWFRAME)
+    UpdateWindow(hWnd)
+
+
 def window_embed(window: tk.Tk, toplevel: tk.Toplevel, iswindow: bool = True):
     def embed():
         SetParent(GetParent(toplevel.winfo_id()), window.winfo_id())
@@ -496,6 +510,70 @@ class DevExtend(tk.Frame):
         self.extend_area.pack(fill=tk.BOTH, expand=tk.YES)
 
 
+class DevHeaderBar(tk.Frame):
+    def __init__(self, master: tk.Tk, border: bool = True, background="#ffffff", double_max: bool = True):
+        super(DevHeaderBar, self).__init__(master=master, background=background, height=35)
+        self.master = master
+        self.master.configure(background="#fdfdfd")
+        self.hWnd = GetParent(self.master.winfo_id())
+        if border:
+            window_border(self.master)
+        elif not border:
+            window_custom_taskbar(self.master)
+        window_move(self, self.master)
+        self.ismaximize = False
+        if double_max:
+            self.bind("<Double-Button-1>", lambda evt: self.maximize())
+
+    def add_close_button(self, text: str = "🗙", font=("微软雅黑", 9),
+                         background="#ffffff", foreground="#000000",
+                         activebackground="#c42b1c", activeforeground="#ffffff"):
+        self.close_button = tk.Button(self, text=text, border=0, font=font,
+                                      background=background, foreground=foreground,
+                                      activebackground=activebackground, activeforeground=activeforeground,
+                                      command=lambda: self.master.destroy())
+        self.close_button.pack(side=tk.RIGHT, ipady=1, ipadx=10, fill=tk.Y)
+
+    def add_maximize_button(self, text: str = "🗖", font=("微软雅黑", 9),
+                            background="#ffffff", foreground="#000000",
+                            activebackground="#e9e9e9", activeforeground="#b5b5b5"):
+        self.maxmize_button = tk.Button(self, text=text, border=0, font=font,
+                                        background=background, foreground=foreground,
+                                        activebackground=activebackground, activeforeground=activeforeground,
+                                        command=self.maximize_event)
+        self.maxmize_button.pack(side=tk.RIGHT, ipady=2, ipadx=12, fill=tk.Y)
+
+    def add_minimize_button(self, text: str = "🗕", font=("微软雅黑", 9),
+                            background="#ffffff", foreground="#000000",
+                            activebackground="#e9e9e9", activeforeground="#b5b5b5"):
+        self.minimize_button = tk.Button(self, text=text, border=0, font=font,
+                                         background=background, foreground=foreground,
+                                         activebackground=activebackground, activeforeground=activeforeground,
+                                         command=self.minimize)
+        self.minimize_button.pack(side=tk.RIGHT, ipady=2, ipadx=12, fill=tk.Y)
+
+    def maximize_event(self):
+        if self.ismaximize:
+            self.master.state("normal")
+            self.maxmize_button.configure(text="🗖")
+            self.ismaximize = False
+        elif not self.ismaximize:
+            self.master.state("zoomed")
+            self.maxmize_button.configure(text="🗗")
+            self.ismaximize = True
+
+    def minimize(self):
+        self.master.state('icon')
+
+    def maximize(self):
+        if self.ismaximize:
+            self.master.state("normal")
+            self.ismaximize = False
+        elif not self.ismaximize:
+            self.master.state("zoomed")
+            self.ismaximize = True
+
+
 class DevImage(tk.Label):
     def __init__(self, master: tk.Widget, image: tk.PhotoImage = None, ):
         super(DevImage, self).__init__(master=master, image=image)
@@ -740,6 +818,7 @@ except NameError:
     pass
 
 
+@deprecated(version='2.3.8', reason="此组件已经启用，请改用DevHeaderBar组件")
 class DevTitleBar(tk.Frame):
     def __init__(self, master: tk.Widget, iswindow: bool = True, window: tk.Tk = None, widget: tk.Widget = None,
                  button_side: str = tk.RIGHT, background="#ffffff",
@@ -991,15 +1070,10 @@ class DevWindow(tk.Tk):
 
     statusbar = wm_statusbar
 
-    def wm_titlebar(self, titleBar: tk.Label = None, overtitlebar: bool = True, border: bool = True):
+    def wm_titlebar(self, titleBar: DevHeaderBar = None, overtitlebar: bool = True, border: bool = True):
         self.minsize(100, 30)
-        if overtitlebar:
-            window_add_taskbar(self)
-        if border:
-            self.remove_titlebar()
         self._titlebar = titleBar
         self._titlebar.pack(fill=tk.X, side=tk.TOP)
-        DevDrag(self._titlebar, self, True)
         return self._titlebar
 
     titlebar = wm_titlebar
@@ -1030,7 +1104,10 @@ class DevToplevel(tk.Toplevel, DevWindow):
 
 
 if __name__ == '__main__':
-    Root = DevWindow()
-    window_popup(Root)
-    window_move(Root, Root)
-    Root.run()
+    Window = DevWindow()
+    HeaderBar = DevHeaderBar(Window, True)
+    HeaderBar.add_close_button()
+    HeaderBar.add_maximize_button()
+    HeaderBar.add_minimize_button()
+    Window.titlebar(HeaderBar)
+    Window.mainloop()
